@@ -19,6 +19,7 @@
 #include <QStyle>
 #include <QStyleFactory>
 #include <QThread>
+#include <QUrlQuery>
 
 #include <KAboutData>
 #include <KColorSchemeManager>
@@ -90,7 +91,6 @@ Application::Application()
     KCrash::initialize();
 
     connect(Global::instance(), &Global::error, this, &Application::error);
-    connect(this, &Application::saveWindowGeometryAsync, Worker::instance(), &Worker::saveWindowGeometry, Qt::QueuedConnection);
 }
 
 Application::~Application()
@@ -181,7 +181,6 @@ void Application::setupCommandLineParser()
 
 void Application::setupQmlSettingsTypes()
 {
-    qmlRegisterSingletonInstance("org.kde.haruna.mpvproperties", 1, 0, "MpvProperties", MpvProperties::self());
     qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "AudioSettings", AudioSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "GeneralSettings", GeneralSettings::self());
     qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "InformationSettings", InformationSettings::self());
@@ -192,22 +191,6 @@ void Application::setupQmlSettingsTypes()
     qmlRegisterSingletonInstance("org.kde.haruna.settings", 1, 0, "VideoSettings", VideoSettings::self());
 }
 
-void Application::restoreWindowGeometry(QQuickWindow *window) const
-{
-    if (!GeneralSettings::rememberWindowGeometry()) {
-        return;
-    }
-    KConfig dataResource(u"data"_s, KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-    KConfigGroup windowGroup(&dataResource, u"Window"_s);
-    KWindowConfig::restoreWindowSize(window, windowGroup);
-    KWindowConfig::restoreWindowPosition(window, windowGroup);
-}
-
-void Application::saveWindowGeometry(QQuickWindow *window)
-{
-    Q_EMIT saveWindowGeometryAsync(window);
-}
-
 bool Application::urlExists(const QUrl &url)
 {
     return pathExists(url.toLocalFile());
@@ -307,9 +290,11 @@ QUrl Application::parentUrl(const QString &path)
     return parentFolderUrl;
 }
 
-bool Application::isYoutubePlaylist(const QString &path)
+bool Application::isYoutubePlaylist(const QUrl &url)
 {
-    return path.contains(u"youtube.com/playlist?list"_s);
+    QUrlQuery query{url.query()};
+    const auto listId = query.queryItemValue(u"list"_s);
+    return !listId.isEmpty();
 }
 
 QString Application::formatTime(const double time)
