@@ -15,6 +15,7 @@
 #include <QJsonDocument>
 #include <QJsonValue>
 #include <QProcess>
+#include <QUrlQuery>
 
 #include <KFileItem>
 #include <KFileMetaData/Properties>
@@ -35,18 +36,26 @@ PlaylistModel::PlaylistModel(QObject *parent)
 {
     connect(this, &PlaylistModel::itemAdded, Worker::instance(), &Worker::getMetaData);
 
-    connect(Worker::instance(), &Worker::metaDataReady, this, [=](int i, KFileMetaData::PropertyMultiMap metaData) {
-        if (m_playlist.isEmpty()) {
+    connect(Worker::instance(), &Worker::metaDataReady, this, [=](int i, const QUrl &url, KFileMetaData::PropertyMultiMap metaData) {
+        if (m_playlist.isEmpty() || i > m_playlist.size()) {
             return;
         }
-        auto duration = metaData.value(KFileMetaData::Property::Duration).toInt();
-        auto title = metaData.value(KFileMetaData::Property::Title).toString();
+        if (m_playlist[i].url == url) {
+            auto duration = metaData.value(KFileMetaData::Property::Duration).toInt();
+            auto title = metaData.value(KFileMetaData::Property::Title).toString();
 
-        m_playlist[i].formattedDuration = Application::formatTime(duration);
-        m_playlist[i].duration = duration;
-        m_playlist[i].mediaTitle = title;
+            m_playlist[i].formattedDuration = Application::formatTime(duration);
+            m_playlist[i].duration = duration;
+            m_playlist[i].mediaTitle = title;
 
-        Q_EMIT dataChanged(index(i, 0), index(i, 0));
+            Q_EMIT dataChanged(index(i, 0), index(i, 0));
+        } else {
+            qDebug() << "\n"
+                     << u"Data missmatch: the url at position %1 received from the worker thread:"_s.arg(i) << "\n"
+                     << u"%1"_s.arg(url.toString()) << "\n"
+                     << u"is different than the url in m_playlist at position %2"_s.arg(i) << "\n"
+                     << u"%1"_s.arg(m_playlist[i].url.toString());
+        }
     });
 }
 
@@ -150,8 +159,7 @@ void PlaylistModel::addItem(const QUrl &url, Behaviour behaviour)
     }
 
     if (url.scheme() == u"http"_s || url.scheme() == u"https"_s) {
-        if (Application::isYoutubePlaylist(url.toString())) {
-            m_playlistPath = url.toString();
+        if (Application::isYoutubePlaylist(url)) {
             getYouTubePlaylist(url, behaviour);
         } else {
             if (behaviour == Behaviour::Clear) {
@@ -263,14 +271,10 @@ void PlaylistModel::addM3uItems(const QUrl &url)
             continue;
         }
 
-        auto url = QUrl::fromUserInput(QString::fromUtf8(line));
-        if (!url.scheme().isEmpty()) {
-            addItem(url, Behaviour::Append);
-        } else {
-            // figure out if it's a relative path
-            url = QUrl::fromUserInput(QString::fromUtf8(line), QFileInfo(m3uFile).absolutePath());
-            addItem(url, Behaviour::Append);
-        }
+        // always set the working directory
+        // it doesn't affect absolute paths and it's required for relative paths
+        auto url = QUrl::fromUserInput(QString::fromUtf8(line), QFileInfo(m3uFile).absolutePath());
+        addItem(url, Behaviour::Append);
 
         if (!matchFound && url == QUrl::fromUserInput(GeneralSettings::lastPlayedFile())) {
             setPlayingItem(i);
@@ -287,9 +291,14 @@ void PlaylistModel::addM3uItems(const QUrl &url)
 
 void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
 {
+    QUrlQuery query{url.query()};
+    QString playlistId{query.queryItemValue(u"list"_s)};
+    QString videoId{query.queryItemValue(u"v"_s)};
+    m_playlistPath = u"https://www.youtube.com/playlist?list=%1"_s.arg(playlistId);
+
     // use youtube-dl to get the required playlist info as json
     auto ytdlProcess = std::make_shared<QProcess>();
-    auto args = QStringList() << u"-J"_s << u"--flat-playlist"_s << url.toString();
+    auto args = QStringList() << u"-J"_s << u"--flat-playlist"_s << m_playlistPath;
     ytdlProcess->setProgram(Application::youtubeDlExecutable());
     ytdlProcess->setArguments(args);
     ytdlProcess->start();
@@ -321,9 +330,19 @@ void PlaylistModel::getYouTubePlaylist(const QUrl &url, Behaviour behaviour)
             Q_EMIT itemAdded(i, item.url.toString());
             endInsertRows();
 
-            if (GeneralSettings::lastPlayedFile().contains(id) && behaviour == Behaviour::Clear) {
-                setPlayingItem(i);
-                matchFound = true;
+            if (videoId.isEmpty()) {
+                // when videoId is not available check if GeneralSettings::lastPlayedFile()
+                // is part of the playlist and set the matching item as playing
+                if (GeneralSettings::lastPlayedFile().contains(id) && !matchFound && behaviour == Behaviour::Clear) {
+                    setPlayingItem(i);
+                    matchFound = true;
+                }
+            } else {
+                // when videoId is available set the item with the same id as playing
+                if (videoId == id && !matchFound && behaviour == Behaviour::Clear) {
+                    setPlayingItem(i);
+                    matchFound = true;
+                }
             }
         }
 
@@ -353,6 +372,8 @@ void PlaylistModel::getHttpItemInfo(const QUrl &url, uint row)
         m_playlist[row].formattedDuration = Application::formatTime(duration);
         m_playlist[row].duration = duration;
 
+        --m_httpItemCounter;
+
         Q_EMIT dataChanged(index(row, 0), index(row, 0));
     });
 }
