@@ -11,6 +11,13 @@
 #include <QObject>
 #include <QtQml/qqmlregistration.h>
 
+struct Track {
+    int trackid{-1};
+    QString lang;
+    QString title;
+    QString codec;
+};
+
 class TracksModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -18,16 +25,32 @@ class TracksModel : public QAbstractListModel
 
 public:
     explicit TracksModel(QObject *parent = nullptr);
-    enum { TextRole = Qt::UserRole, LanguageRole, TitleRole, IDRole, CodecRole };
+
+    // clang-format off
+    enum Roles {
+        IdRole = Qt::UserRole,
+        TextRole,
+        LanguageRole,
+        TitleRole,
+        CodecRole
+    };
+    Q_ENUM(Roles)
+    // clang-format on
+
+    Q_PROPERTY(int rowCount READ rowCount NOTIFY rowCountChanged)
+    Q_SIGNAL void rowCountChanged();
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     QHash<int, QByteArray> roleNames() const override;
 
+    void clear();
+    void addTrack(Track track);
+
 public Q_SLOTS:
-    void setTracks(QList<QVariant> tracks);
+    void setTracks(QList<Track> tracks);
 
 private:
-    QList<QVariant> m_tracks;
+    QList<Track> m_tracks;
 };
 
 #endif // TRACKSMODEL_H
