@@ -8,14 +8,20 @@
 #define MPVPROPERTIES_H
 
 #include <QObject>
+#include <qqmlintegration.h>
 
 using namespace Qt::StringLiterals;
 
 class MpvProperties : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
+    explicit MpvProperties(QObject *parent = nullptr)
+        : QObject(parent)
+    {}
     static MpvProperties *self()
     {
         static MpvProperties p;
@@ -215,15 +221,7 @@ public:
     const QString TracksCount{u"track-list/count"_s};
 
 private:
-    explicit MpvProperties(QObject *parent = nullptr)
-        : QObject(parent)
-    {
-    }
-
-    MpvProperties(const MpvProperties &) = delete;
-    MpvProperties &operator=(const MpvProperties &) = delete;
-    MpvProperties(MpvProperties &&) = delete;
-    MpvProperties &operator=(MpvProperties &&) = delete;
+    Q_DISABLE_COPY_MOVE(MpvProperties)
 };
 
 #endif // MPVPROPERTIES_H
