@@ -25,18 +25,19 @@ public:
     static Worker *instance();
 
 Q_SIGNALS:
-    void metaDataReady(uint index, KFileMetaData::PropertyMultiMap metadata);
+    void metaDataReady(uint index, const QUrl &url, KFileMetaData::PropertyMultiMap metadata);
     void thumbnailSuccess(const QString &path, const QImage &image);
     void thumbnailFail();
     void mprisThumbnailSuccess(const QImage &image);
+    void subtitlesFound(QStringList subs);
 
 public Q_SLOTS:
     void getMetaData(uint index, const QString &path);
     void makePlaylistThumbnail(const QString &path, int width);
     QImage frameToImage(const QString &path, int width);
     void syncConfigValue(QString path, QString group, QString key, QVariant value);
-    void saveWindowGeometry(QQuickWindow *window) const;
     void mprisThumbnail(const QString &path, int width);
+    void findRecursiveSubtitles(const QUrl &url);
 
 private:
     Worker() = default;
